function [T, P, V_inf, alpha_e, beta_i_07] = LL_iter(N, R, dr, r, y, tm, c, fi, n_rev, V_s, R_boss, Z, rho_s, C_Lc_wag, nu_s, w, D)
% This function calculates the performance of the propeller using lifting
% line theory

% Calculating advance velocity and beta
V_adv = V_s.*(1-w);
beta = atan(V_adv./(2*pi*r*n_rev));

% Assuming first value for beta_i to be equal to beta, i.e no induced
% velocities
beta_i = beta;

% Assuming first values of circulation to be elliptical
gamma_0 = 1;
gamma = gamma_0 * sqrt(1-((2.*((r-R_boss)./(R-R_boss))-1).^2));

% Defining the zero lift coefficient based on results from Xfoil
r_R_wag = [0.2 0.3 0.4 0.5 0.6 0.7 0.8 0.9 1.0];
C_Lc = interp1(r_R_wag, C_Lc_wag, y, 'pchip');

% Defining iteration variables
iter = 1;
iter_max = 1000;
difference_gamma = 1;
difference_beta_i = 1;
damping_gamma = 0.005;

while difference_gamma>0.00001 && difference_beta_i>0.00001 && iter<iter_max
    
    %Numerical differentiation of the circulation using cubic spline fit
    gamma_spline = csapi(r, gamma);
    dgamma_dr = fnval(r, fnder(gamma_spline, 1));
    
    % Inductions factors
    [I_A, I_T] = induction_factors(y, Z, beta_i);
    
    % Calculating the induced velocities by numerical integration
    % Preallocation
    integrand_A = zeros(N,N);
    integrand_T = zeros(N,N);
    
    for n = 1:N
        for i = 1:N
            if n ~= i
                integrand_A(n,i)=(I_A(n,i)*dgamma_dr(i))/(r(n)-r(i));
                integrand_T(n,i)=(I_T(n,i)*dgamma_dr(i))/(r(n)-r(i));
            end
        end
    end
    
    % Correcting for singularity when n=i
    for n = 1:N
        for i = 1:N
            if i-1 == 0
                integrand_A(1,1) = integrand_A(1,2) + (integrand_A(1,2) - integrand_A(1,3));
                integrand_T(1,1) = integrand_T(1,2) + (integrand_T(1,2) - integrand_T(1,3));
            elseif i+1 == N+1
                integrand_A(N,N) = integrand_A(N,N-1) + (integrand_A(N,N-2) - integrand_A(N,N-3));
                integrand_T(N,N) = integrand_T(N,N-1) + (integrand_T(N,N-2) - integrand_T(N,N-3));
            elseif i == n
                integrand_A(n,i) = 0.5*(integrand_A(n,i-1) + integrand_A(n,i+1));
                integrand_T(n,i) = 0.5*(integrand_T(n,i-1) + integrand_T(n,i+1));
            end
        end
    end
    
    % Integrating with the trapezoidal rule to calculate induced velocities
    U_A = (1/(4*pi)).*trapz(transpose(integrand_A)).*dr;
    U_T = (1/(4*pi)).*trapz(transpose(integrand_T)).*dr;
    
    % Removing singularities at the ends by extrapolating U_A(N) and U_T(N)
    U_A(1) = U_A(2);
    U_A(N) = U_A(N-1);
    U_T(1) = U_T(2);
    U_T(N) = U_T(N-1);
    
    % Resulting inflow velocity at each foil section of propeller blade
    V_inf = ((V_adv+U_A).^2 + (2.*pi.*r.*n_rev-U_T).^2).^0.5;
    
    % New hydrodynamic pitch angle, including the effects of induced
    % velocities
    beta_i_new = atan((V_adv+U_A)./(2.*pi.*r.*n_rev-U_T));
    
    % Resulting effective angle of attack
    alpha_e = fi-beta_i_new;
    
    % Section lift coefficients
    C_L = 2.*pi.*alpha_e + C_Lc./c;
    
    % Calculating circulation distribution from lift coefficients and
    % Kutta-Joukowski theorem
    gamma_new = 0.5.*V_inf.*C_L.*c;
    
    %Forcing end values of new gamma to be 0
    gamma_new(N) = 0;
    gamma_new(1) = 0;
    
    % Difference between the circulation distributions
    difference_gamma = max(abs(gamma_new-gamma));
    difference_beta_i = max(abs(beta_i_new-beta_i));
    
    % Updating values for input to the next iteration
    beta_i = beta_i_new;
    gamma = gamma + damping_gamma.*(gamma_new - gamma);
    gamma(N) = 0;
    gamma(1) = 0;
    iter = iter+1;
    
end

% Separating beta_i at 1.0*R for use in pitch iteration
% Finding the index for 1.0*R
index_07 = find(round(y,1) == 1, 1, 'first');
beta_i_07 = beta_i(index_07);

% Ensuring convergence by setting the thrust and torque to a very small
% value if the lifting line calculations reaches the maximum number of
% iterations
if iter < 1000
    
    %Calculating the corresponding advance numbers
    J_0 = V_s/(n_rev*D);
    
    % The Reynolds number at all radial positions can be found as
    Re_s = (n_rev.*(sqrt((J_0.*D).^2 + (2.*pi.*r).^2)).*c)./nu_s;
    Re_s(N) = 0;
    
    % Frictional resistance coefficient according to ITTC'75
    C_Fs = 0.075./((log10(Re_s)-2).^2);
    
    % Viscous drag coefficient with ITTC'75 frictional coefficient (equation
    % 6.19 page 58 in propeller compendium)
    C_D = 2.*C_Fs.*(1+(2.*tm./c).*(1+(C_L.^2)./8));
    C_D(N) = 0;
    
    % Drag of each section
    dD = 0.5.*rho_s.*(V_inf.^2).*C_D.*c.*dr;
    
    % Thrust and torque of each section
    dT = rho_s.*gamma.*(2.*pi.*r.*n_rev - U_T).*dr - dD.*sin(beta_i);
    dQ = rho_s.*gamma.*(V_adv + U_A).*r.*dr + dD.*cos(beta_i).*r;
    
    % Summing up over all blades to find total thrust and torque of propeller
    T = sum(dT)*Z;
    Q = sum(dQ)*Z;
    
    % Avoiding negtive values of thrust
    if T < 0
        T = 1e-10;
    end
    
    % Avoiding negtive values of torque
    if Q < 0
        Q = 1e100;
    end
    
else
    % Setting the thrust and torque very small if the lifting line
    % calculations has not converged
    T = 1e-20;
    Q = 1e200;
end

% The effect delivered to the propeller is
P = 2*pi*n_rev*Q;

end