function [x, fval] = runnested(x_0, T_req, penalty_thr)
%% Optimization
% In this section, the optimization algorithm is called and its properties 
% are defined. For each configuration, the following should be defined:

% * lb and ub. Their length should be adjusted according to the number of optimization variables. No need to define new values, just the length of the vectors should be adjusted

% Defining constraints
A = [];
b = [];
Aeq = [];
beq = [];
lb = [0.3 0.4 0.4 0.4 0.4];
ub = [1.05 5 5 5 5];
nonlcon = [];

% Optimons for the optimization algorithm
options = optimoptions('fmincon', 'MaxIterations', 40, 'FunctionTolerance', 1e-3, 'StepTolerance', 1e-3, 'ConstraintTolerance', 1e-3,...
    'OptimalityTolerance', 1e-3, 'PlotFcn', @optimplotfval);

% Finding the optimal geometry by calling the fmincon function
[x, fval] = fmincon(@main, x_0, A, b, Aeq, beq, lb, ub, nonlcon, options);

%% Objective function
    function objective = main(x)
        % This is the objective function of the optimization procedure. 
        % For each configuration, the following should be defined:
        
        % *Open water advance numbers J_0_1 to J_0_X
        % *Configuration of open water advance numbers J_0 = [J_0_1,....,J_0_X]. Use symmetry to reduce computational time
        % * row and col, which is the number of propellers vertically and horizontally, respectively
        % * Make sure that the same properties are also altered in the main_no_opt.m function
        
        % Defining the variables to be optimized. Must be adjusted for 
        % each configuration
        AEA0 = x(1);
        J_0_1 = x(2);
        J_0_2 = x(3);
        J_0_3 = x(4);
        J_0_4 = x(5);
        
        % Collecting all advance numbers in one vector. J_0_1 is the centre 
        % propeller
        J_0 = [J_0_4 J_0_3 J_0_2 J_0_1 J_0_2 J_0_3 J_0_4];
        
        % Defining number of propeller blades
        Z = 4;
        
        % Importing input data
        [rho_s, g, nu_s, pv, pa, V_m, V_s, BWL_m, scale, C_B, C_WA] = input();
        
        % Defining the number of propellers vertically and horizontally in 
        % each configuration
        row = 1;
        col = 7;
        
        % The number of propellers in the configuration then becomes
        np = row*col;
        
        % Propeller centre coordinates and diameter
        [D, h, y_centre, z_centre] = diameter_calc(row, col, BWL_m, scale);
        
        % Calculating the rate of revolution from J_0
        n_rev = V_s./(J_0.*D);
        
        % Importing variables
        [N, R, R_boss, dr, r, y, theta] = variables(D);
        
        % Importing interpolated wake
        [w_s, y_wake, z_wake] = wake(V_m, BWL_m, scale);
        
        % Preallocation
        T = zeros(length(theta), np);
        P = zeros(length(theta), np);
        eta_H = zeros(length(theta), np);
        beta_i_07 = zeros(1, np);
        PD_07 = zeros(1, np);
        fi_07 = zeros(1, np);
        
        % Analyzing the performance of each propeller in the configuration
        for i = 1:np
            
            % First value of pitch angle
            [fi_07(i), r_07] = pitch(y, r, V_s, n_rev(i));
            
             % Other first values
            iter = 1;
            search_pitch = 0;
            
            while search_pitch == 0
                
                % Importing geometry
                [tm, c, fi, tm_interp, c_interp, b_interp, r_R_interp, PD_07(i)] = wag_geo(D, Z, y, r, AEA0, fi_07(i), r_07);
                
                % Sending the geometry into Xfoil, and returning the camber 
                % lift coefficient of the foil sections
                [C_Lc_wag] = xfoil(b_interp, tm_interp, c_interp, r_R_interp);
                
                % The performance of the propeller is calculated in the 
                % following function
                [T(:,i), P(:,i), eta_H(:,i), beta_i_07(i)] = analysis_nested(y_centre(i), z_centre(i), r, N, theta, y_wake, z_wake, w_s, C_B, C_WA, D, R, dr, y, tm, c, fi, n_rev(i), V_s, R_boss, Z, rho_s, nu_s, C_Lc_wag);
                
                % The pitch of each propeller is determined by iteration
                if fi_07(i) > 1.01*beta_i_07(i) || fi_07(i) < 0.99*beta_i_07(i)
                    fi_07(i) = beta_i_07(i);
                    search_pitch = 0;
                else
                    search_pitch = 1;
                end
                
                % Updating iteration number
                iter = iter+1;
                
            end
            
        end
        
        
        % Thrust is averaged over the angular position of lifting line 
        % that contributes to thrust
        T_tot_mean_ang = mean(T,1);
        P_tot_mean_ang = mean(P,1);
        
        % The total thrust delivered is the sum of the thrust from all 
        % propellers
        T_tot = sum(T_tot_mean_ang); %[N]
        P_tot = sum(P_tot_mean_ang); %[W]
        
        % Objective
        obj = P_tot/(T_req*V_s) + penalty_thr*(1-(T_req/T_tot))^2;
        objective = obj;
        
    end

end

