function [T_tot, eta, cav_tot, row, col, Z, D, theta, P_tot, PD_07] = main_no_opt(x)
% This function analyses the propellers without optimizing geometry. 
% The geometry from the optimization is input. For each configuration, 
% the following should be defined:

% *Open water advance numbers J_0_1 to J_0_(X+1)
% *Configuration of open water advance numbers J_0 = [J_0_1,....,J_0_X]. Use symmetry to reduce computational time
% * J_0_(X+1) is the advance number of the large propeller. It should be adjusted in the expression for rate of revolution for the large propeller such that n_rev = V_s./(J_0_(X+1).*D);
% * row and col, which is the number of propellers vertically and horizontally, respectively
% * Make sure that the same properties are also altered in the runnested.m function

% If this function is commented such that this becomes a script, 
% the resulting geometry from text files can be manually defined such that 
% the performance can be calculated without running the whole optimization.
% This has been done when calculating the thrust loading coefficient 
% and hull efficiency per definition

% Defining the geometrical properties based on the optimized variables.
AEA0 = x(1);
J_0_1 = x(2);
J_0_2 = x(3);
J_0_3 = x(4);
J_0_4 = x(5);
J_0_5 = x(6);

%% In this section the grid of propellers are treated
% Collecting all advance numbers in one vector. J_0_1 is the centre 
% propeller while J_0_X is the outermost propellers
J_0 = [J_0_4 J_0_3 J_0_2 J_0_1 J_0_2 J_0_3 J_0_4];

% Defining number of propeller blades
Z = 4;

% Importing input data
[rho_s, g, nu_s, pv, pa, V_m, V_s, BWL_m, scale, C_B, C_WA] = input();

% Defining the number of propellers vertically and horizontally in each 
% configuration
row = 1;
col = 7;

% The number of propellers in the configuration then becomes
np = row*col;

% Propeller centre coordinates and diameter
[D, h, y_centre, z_centre] = diameter_calc(row, col, BWL_m, scale);

% Calculating the rate of revolution from J_0
n_rev = V_s./(J_0.*D);

% Importing variables
[N, R, R_boss, dr, r, y, theta] = variables(D);

% Importing interpolated wake
[w_s, y_wake, z_wake] = wake(V_m, BWL_m, scale);

% Preallocation
T = zeros(length(theta), np);
P = zeros(length(theta), np);
cav_points = zeros(1, np);
eta_H = zeros(length(theta), np);
beta_i_07 = zeros(1, np);
PD_07 = zeros(1, np);
fi_07 = zeros(1, np);

% Analyzing the perfomance of each propeller in the configuration
for i = 1:np
    
    % Propeller number prop_num is now analyzed
    prop_num = i;
    
    % First value of pitch angle
    [fi_07(i), r_07] = pitch(y, r, V_s, n_rev(i));
    
    % Other first values
    iter = 1;
    search_pitch = 0;
    
    while search_pitch == 0
        
        % Importing geometry
        [tm, c, fi, tm_interp, c_interp, b_interp, r_R_interp, PD_07(i)] = wag_geo(D, Z, y, r, AEA0, fi_07(i), r_07);
        
        % Sending the geometry into Xfoil, and returning the camber lift 
        % coefficient of the foil sections
        [C_Lc_wag] = xfoil(b_interp, tm_interp, c_interp, r_R_interp);
        
        % The performance of th propeller is calculated in this function
        [T(:,i), P(:,i), cav_points(:,i), eta_H(:,i), beta_i_07(i)] = analysis(y_centre(i), z_centre(i), r, N, theta, y_wake, z_wake, w_s, C_B, C_WA, D, R, dr, y, tm, c, fi, n_rev(i), V_s, R_boss, Z, rho_s, g, pa, pv, nu_s, h, C_Lc_wag, r_R_interp, fi_07(i), prop_num);
        
        % The pitch of each propeller is determined by iteration
        if fi_07(i) > 1.01*beta_i_07(i) || fi_07(i) < 0.99*beta_i_07(i)
            fi_07(i) = beta_i_07(i);
            search_pitch = 0;
        else
            search_pitch = 1;
        end
        
        % Updating iteration number
        iter = iter+1;
        
    end
    
end

%% Treating the large propeller
% Importing propeller centre coordinates and diameter
[D, h, y_centre, z_centre] = diameter_calc_T(scale);

% Calculating the rate of revolution from J_0
n_rev = V_s./(J_0_5.*D);

% Importing variables
[N, R, R_boss, dr, r, y, theta] = variables(D);

% Importing interpolated wake
[w_s, y_wake, z_wake] = wake(V_m, BWL_m, scale);

% Propeller number prop_num is now analyzed. It is (X+1) is there is X 
% number of propellers that is optimized in the grid
prop_num = 8;

% First value of pitch angle
[fi_07, r_07] = pitch(y, r, V_s, n_rev);

% Other first values
iter = 1;
search_pitch = 0;

while search_pitch == 0
    
    % Importing geometry
    [tm, c, fi, tm_interp, c_interp, b_interp, r_R_interp, PD_07] = wag_geo(D, Z, y, r, AEA0, fi_07, r_07);
    
    % Sending the geometry into Xfoil, and returning the camber lift 
    % coefficient of the foil sections
    [C_Lc_wag] = xfoil(b_interp, tm_interp, c_interp, r_R_interp);
    
    % The performance of th propeller is calculated in this function
    [T_large, P_large, cav_points_large, eta_H_large, beta_i_07_large] = analysis_T(y_centre, z_centre, r, N, theta, y_wake, z_wake, w_s, C_B, C_WA, D, R, dr, y, tm, c, fi, n_rev, V_s, R_boss, Z, rho_s, g, pa, pv, nu_s, h, C_Lc_wag, r_R_interp, fi_07, prop_num);
    
    if fi_07 > 1.01*beta_i_07_large || fi_07 < 0.99*beta_i_07_large
        fi_07 = beta_i_07_large;
        search_pitch = 0;
    else
        search_pitch = 1;
    end
    
    iter = iter+1;
    
end

%% Combinding the resulting performance of the propellers in the grid and the large propeller
%Thrust is averaged over the angular positon of lifting line that 
% contributes to thrust
T_tot_mean_ang = mean(T,1);
P_tot_mean_ang = mean(P,1);

% The total thrust delivered is the sum of the thrust from all propellers
T_tot = sum(T_tot_mean_ang) + mean(T_large); %[N]                    
P_tot = sum(P_tot_mean_ang) + mean(P_large); %[W]

% Number of cavitation points for each propeller are added 
cav_tot = sum(cav_points) + cav_points_large;

% Combinding the contributions to propulsive efficiency from thrust 
% deduction fractions
eta_H_mean = mean(mean(eta_H));
eta_HH = [eta_H_mean mean(eta_H_large)];

% The resulting efficiency then becomes
eta = ((T_tot*V_s)/P_tot)*mean(eta_HH);

end