function [x, fval] = runnested(x_0, T_req, penalty_thr)
%% Optimization
% In this section, the optimization algorithm is called and its properties 
% are defined. For each configuration, the following should be defined:

% * lb and ub. Their length should be adjusted according to the number of optimization variables. No need to define new values, just the length of the vectors should be adjusted

% Defining constraints
A = [];
b = [];
Aeq = [];
beq = [];
lb = [0.3 0.4 0.4 0.4 0.4 0.4];
ub = [1.05 2 2 2 2 2];
nonlcon = [];

% Optimons for the optimization algorithm
options = optimoptions('fmincon', 'MaxIterations', 40, 'FunctionTolerance', 1e-3, 'StepTolerance', 1e-3, 'ConstraintTolerance', 1e-3,...
    'OptimalityTolerance', 1e-3, 'PlotFcn', @optimplotfval);

% Finding the optimal geometry by calling the fmincon function
[x, fval] = fmincon(@main, x_0, A, b, Aeq, beq, lb, ub, nonlcon, options);

%% Objective function
    function objective = main(x)
        % This is the objective function of the optimization procedure. 
        % For each configuration, the following should be defined:
        
        % *Open water advance numbers J_0_1 to J_0_(X+1)
        % *Configuration of open water advance numbers J_0 = [J_0_1,....,J_0_X]. Use symmetry to reduce computational time
        % * J_0_(X+1) is the advance number of the large propeller. It should be adjusted in the expression for rate of revolution for the large propeller such that n_rev = V_s./(J_0_(X+1).*D);
        % * row and col, which is the number of propellers vertically and horizontally, respectively
        % * Make sure that the same properties are also altered in the main_no_opt.m function
        
        % Defining the variables to be optimized. Must be adjusted for 
        % each configuration
        AEA0 = x(1);
        J_0_1 = x(2);
        J_0_2 = x(3);
        J_0_3 = x(4);
        J_0_4 = x(5);
        J_0_5 = x(6);
        
        %% In this section the grid of propellers are treated
        % Collecting all advance numbers in one vector. J_0_1 is the centre 
        % propeller while J_0_X is the outermost propellers
        J_0 = [J_0_4 J_0_3 J_0_2 J_0_1 J_0_2 J_0_3 J_0_4];
        
        % Defining number of propeller blades
        Z = 4;
        
        % Importing input data
        [rho_s, g, nu_s, pv, pa, V_m, V_s, BWL_m, scale, C_B, C_WA] = input();
        
        % Defining the number of propellers vertically and horizontally in
        % each configuration
        row = 1;
        col = 7;
        
        % The number of propellers in the configuration then becomes
        np = row*col;
        
        % Propeller centre coordinates and diameter
        [D, h, y_centre, z_centre] = diameter_calc(row, col, BWL_m, scale);
        
        % Calculating the rate of revolution from J_0
        n_rev = V_s./(J_0.*D);
        
        % Importing variables
        [N, R, R_boss, dr, r, y, theta] = variables(D);
        
        % Importing interpolated wake
        [w_s, y_wake, z_wake] = wake(V_m, BWL_m, scale);
        
        % Preallocation
        T = zeros(length(theta), np);
        P = zeros(length(theta), np);
        cav_points = zeros(1, np);
        eta_H = zeros(length(theta), np);
        beta_i_07 = zeros(1, np);
        PD_07 = zeros(1, np);
        fi_07 = zeros(1, np);
        
        % Analyzing the perfomance of each propeller in the configuration
        for i = 1:np
            
            % Propeller number prop_num is now analyzed
            prop_num = i;
            
            % First value of pitch angle
            [fi_07(i), r_07] = pitch(y, r, V_s, n_rev(i));
            
            % Other first values
            iter = 1;
            search_pitch = 0;
            
            while search_pitch == 0
                
                % Importing geometry
                [tm, c, fi, tm_interp, c_interp, b_interp, r_R_interp, PD_07(i)] = wag_geo(D, Z, y, r, AEA0, fi_07(i), r_07);
                
                % Sending the geometry into Xfoil, and returning the camber 
                % lift coefficient of the foil sections
                [C_Lc_wag] = xfoil(b_interp, tm_interp, c_interp, r_R_interp);
                
                % The performance of the propeller is calculated in the 
                % following function
                [T(:,i), P(:,i), cav_points(:,i), eta_H(:,i), beta_i_07(i)] = analysis(y_centre(i), z_centre(i), r, N, theta, y_wake, z_wake, w_s, C_B, C_WA, D, R, dr, y, tm, c, fi, n_rev(i), V_s, R_boss, Z, rho_s, g, pa, pv, nu_s, h, C_Lc_wag, r_R_interp, fi_07(i), prop_num);
                
                % The pitch of each propeller is determined by iteration
                if fi_07(i) > 1.01*beta_i_07(i) || fi_07(i) < 0.99*beta_i_07(i)
                    fi_07(i) = beta_i_07(i);
                    search_pitch = 0;
                else
                    search_pitch = 1;
                end
                
                % Updating iteration number
                iter = iter+1;
                
            end
            
        end
        
        %% Treating the large propeller
        % Importing propeller centre coordinates and diameter
        [D, h, y_centre, z_centre] = diameter_calc_T(scale);
        
        % Calculating the rate of revolution from J_0
        n_rev = V_s./(J_0_5.*D);
        
        % Importing variables
        [N, R, R_boss, dr, r, y, theta] = variables(D);
        
        % Importing interpolated wake
        [w_s, y_wake, z_wake] = wake(V_m, BWL_m, scale);
        
        % Propeller number prop_num is now analyzed
        prop_num = 1;
        
        % First value of pitch angle
        [fi_07, r_07] = pitch(y, r, V_s, n_rev);
        
        % Other first values
        iter = 1;
        search_pitch = 0;
        
        while search_pitch == 0
            
            % Importing geometry
            [tm, c, fi, tm_interp, c_interp, b_interp, r_R_interp, PD_07] = wag_geo(D, Z, y, r, AEA0, fi_07, r_07);
            
            % Sending the geometry into Xfoil, and returning the camber 
            % lift coefficient of the foil sections
            [C_Lc_wag] = xfoil(b_interp, tm_interp, c_interp, r_R_interp);
            
            % The performance of the propeller is calculated in the
            % following function
            [T_large, P_large, cav_points_large, eta_H_large, beta_i_07_large] = analysis_T(y_centre, z_centre, r, N, theta, y_wake, z_wake, w_s, C_B, C_WA, D, R, dr, y, tm, c, fi, n_rev, V_s, R_boss, Z, rho_s, g, pa, pv, nu_s, h, C_Lc_wag, r_R_interp, fi_07, prop_num);
            
            % The pitch of each propeller is determined by iteration
            if fi_07 > 1.01*beta_i_07_large || fi_07 < 0.99*beta_i_07_large
                fi_07 = beta_i_07_large;
                search_pitch = 0;
            else
                search_pitch = 1;
            end
            
            % Updating iteration number
            iter = iter+1;
            
        end
        
        %% Combinding the resulting performance of the propellers in the grid and the large propeller
        % Thrust is averaged over the angular positon of lifting line 
        % that contributes to thrust
        T_tot_mean_ang = mean(T,1);
        P_tot_mean_ang = mean(P,1);
        
        % The total thrust delivered is the sum of the thrust from all 
        % propellers
        T_tot = sum(T_tot_mean_ang) + mean(T_large); %[N]
        P_tot = sum(P_tot_mean_ang) + mean(P_large); %[W]
        
        % Objective
        obj = P_tot/(T_req*V_s) + penalty_thr*(1-(T_req/T_tot))^2;
        objective = obj;
        
    end

end

